@@ -1,11 +1,20 @@
 from pushsource._impl import Source, SourceUrlError
 from pushsource._impl.model import (
     PushItem,
+    KojiBuildInfo,
     FilePushItem,
     CompsXmlPushItem,
     ModuleMdPushItem,
+    ModuleMdSourcePushItem,
     ProductIdPushItem,
     RpmPushItem,
+    ContainerImagePushItem,
+    ContainerImagePullSpec,
+    ContainerImageDigestPullSpec,
+    ContainerImageTagPullSpec,
+    ContainerImagePullInfo,
+    SourceContainerImagePushItem,
+    OperatorManifestPushItem,
     AmiPushItem,
     AmiRelease,
     AmiBillingCodes,
@@ -16,4 +25,9 @@ from pushsource._impl.model import (
     ErratumPackageCollection,
 )
 
-from pushsource._impl.backend import ErrataSource, KojiSource, StagedSource
+from pushsource._impl.backend import (
+    ErrataSource,
+    KojiSource,
+    StagedSource,
+    RegistrySource,
+)
