@@ -1,6 +1,14 @@
 import logging
 
-import kobo.rpmlib
+try:
+    from kobo import rpmlib
+except Exception as ex:  # pragma: no cover, pylint: disable=broad-except
+    # If kobo.rpmlib is unavailable, let's not immediately crash.
+    # We will hold this exception and re-raise it only if there's an
+    # attempt to use the related functionality.
+    from .. import broken_rpmlib as rpmlib
+
+    rpmlib.CAUSE = ex
 
 from ...model import RpmPushItem
 from .staged_base import StagedBaseMixin, handles_type
@@ -19,8 +27,8 @@ class StagedRpmMixin(StagedBaseMixin):
             LOG.warning("Unexpected non-RPM %s (ignored)", entry.path)
             return None
 
-        header = kobo.rpmlib.get_rpm_header(entry.path)
-        key_id = kobo.rpmlib.get_keys_from_header(header)
+        header = rpmlib.get_rpm_header(entry.path)
+        key_id = rpmlib.get_keys_from_header(header)
 
         return RpmPushItem(
             name=entry.name,
